instrumenttools.iterate_notes_and_chords_in_expr_outside_traditional_instrument_ranges
======================================================================================

.. autofunction:: abjad.tools.instrumenttools.iterate_notes_and_chords_in_expr_outside_traditional_instrument_ranges.iterate_notes_and_chords_in_expr_outside_traditional_instrument_ranges
